package com.unis.auth.feign;

import com.alibaba.fastjson.JSONObject;
import com.unis.common.utils.ResponseWrapper;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.*;

/**
 * @author lidiaoquan
 * @version 1.0
 * @Title: BaseServerClient
 * @ProjectName cblservice
 * @Description: 公共基础服务
 * @date 2019年8月14日 下午2:45:17
 */
@FeignClient("base-server")
@Component
public interface BaseServerClient {

	/**
	 * 根据企业机构代码查询企业
	 * 
	 * @param qyjgdm
	 * @return
	 */
	@GetMapping(value = "/organization/{qyjgdm}")
	@ApiOperation(value = "根据企业机构代码查询企业", notes = "参数：企业机构代码")
	public ResponseWrapper selectQy(@PathVariable("qyjgdm") String qyjgdm);

	/**
	 * @author huangxing
	 * @Description 获取库点列表
	 * @return 库点信息列表
	 */
	@ApiOperation(value = "获取库点信息列表", notes = "参数：库点名称，粮库类别，企业编号，企业名称，库点企业性质")
	@PostMapping(value = "/dKdxxsjy/getDKdxxsjyList")
	public ResponseWrapper getDKdxxsjyList(@RequestBody JSONObject dKdxxsjyVO);
	
	/**
	 * @author zhengbodang
	 * @Description 获取粮食库存列表
	 * @param 
	 * @return 粮食库存列表
	 */
	@ApiOperation(value = "粮食库存列表", notes = "参数：")
	@PostMapping(value = "/lskcxx/getTyLskcxxList")
	public ResponseWrapper getTyLskcxxList(@RequestBody JSONObject tyLskcxxVO);
	
	/**
	 * @author zhengbodang
	 * @Description 根据库点编号获取仓房列表
	 * @param 
	 * @return 粮食库存列表
	 */
	@ApiOperation(value = "根据库点编号获取仓房列表", notes = "参数：")
	@PostMapping(value = "/dCfxxsjy/getDCfxxxsjyList")
	public ResponseWrapper getDCfxxxsjyList(@RequestBody JSONObject tyLskcxxVO);
	
	/**
	 * @author zhengbodang
	 * @Description 根据库点编号获取油罐信息列表
	 * @param 
	 * @return 粮食库存列表
	 */
	@ApiOperation(value = "根据库点编号获取油罐信息列表", notes = "参数：kddm")
	@PostMapping(value = "/dYgxxsjy/getDYgxxxsjyList")
	public ResponseWrapper getDYgxxxsjyList(@RequestBody JSONObject tyLskcxxVO);
	
	
}
